@@ -313,29 +313,16 @@ void print_header(FILE *& file) {
 	fprintf(file, "%s", "##ALT=<ID=INV,Description=\"Inversion\">\n");
 	fprintf(file, "%s", "##ALT=<ID=BND,Description=\"Translocation\">\n");
 	fprintf(file, "%s", "##ALT=<ID=INS,Description=\"Insertion\">\n");
-	fprintf(file, "%s", "##INFO=<ID=CIEND,Number=1,Type=String,Description=\"PE confidence interval around END\">\n");
-	fprintf(file, "%s", "##INFO=<ID=CIPOS,Number=1,Type=String,Description=\"PE confidence interval around POS\">\n");
 	fprintf(file, "%s", "##INFO=<ID=CHR2,Number=1,Type=String,Description=\"Chromosome for END coordinate in case of a translocation\">\n");
 	fprintf(file, "%s", "##INFO=<ID=END,Number=1,Type=Integer,Description=\"End position of the structural variant\">\n");
-	fprintf(file, "%s", "##INFO=<ID=MAPQ,Number=1,Type=Integer,Description=\"Median mapping quality of paired-ends\">\n");
-	fprintf(file, "%s", "##INFO=<ID=RE,Number=1,Type=Integer,Description=\"read support\">\n");
 	fprintf(file, "%s", "##INFO=<ID=IMPRECISE,Number=0,Type=Flag,Description=\"Imprecise structural variation\">\n");
 	fprintf(file, "%s", "##INFO=<ID=PRECISE,Number=0,Type=Flag,Description=\"Precise structural variation\">\n");
-	fprintf(file, "%s", "##INFO=<ID=AVGLEN,Number=1,Type=Float,Description=\"Length of the SV\">\n");
+	fprintf(file, "%s", "##INFO=<ID=SVLEN,Number=1,Type=Float,Description=\"Length of the SV\">\n");
 	fprintf(file, "%s", "##INFO=<ID=SVMETHOD,Number=1,Type=String,Description=\"Vector of samples supporting the SV.\">\n");
 	fprintf(file, "%s", "##INFO=<ID=SVTYPE,Number=1,Type=String,Description=\"Type of the SV.\">\n");
-	fprintf(file, "%s", "##INFO=<ID=SUPP_VEC,Number=1,Type=String,Description=\"Number of samples supporting the variant.\">\n");
-	fprintf(file, "%s", "##INFO=<ID=SUPP,Number=1,Type=String,Description=\"Previous support vector\">\n");
 	fprintf(file, "%s", "##INFO=<ID=STRANDS,Number=1,Type=String,Description=\"Indicating the direction of the reads with respect to the type and breakpoint.\">\n");
 	fprintf(file, "%s", "##FORMAT=<ID=GT,Number=1,Type=String,Description=\"Genotype\">\n");
-	fprintf(file, "%s", "##FORMAT=<ID=LN,Number=1,Type=Integer,Description=\"predicted length\">\n");
-	fprintf(file, "%s", "##FORMAT=<ID=DR,Number=1,Type=Integer,Description=\"# supporting reference,variant reads in that order\">\n");
-	fprintf(file, "%s", "##FORMAT=<ID=ST,Number=1,Type=String,Description=\"Strand of SVs\">\n");
-	fprintf(file, "%s", "##FORMAT=<ID=TY,Number=1,Type=String,Description=\"Types\">\n");
-	fprintf(file, "%s", "##FORMAT=<ID=CO,Number=1,Type=String,Description=\"Coordinates\">\n");
-	fprintf(file, "%s", "##FORMAT=<ID=PSV,Number=1,Type=String,Description=\"Previous support vector\">\n");
-
-	fprintf(file, "%s", "#CHROM\tPOS\tID\tREF\tALT\tQUAL\tFILTER\tINFO\tFORMAT\n");
+	fprintf(file, "%s", "#CHROM\tPOS\tID\tREF\tALT\tQUAL\tFILTER\tINFO\tFORMAT\tSample\n");
 }
 
 std::string print_entry_bed(strvcfentry & region) {
@@ -350,20 +337,15 @@ std::string print_entry_bed(strvcfentry & region) {
 	convert << "00";
 	convert << "BED\tN\t<";
 	convert << trans_type(region.type);
-	convert << ">\t.\tLowQual\tIMPRECISE;SVTYPE=";
+	convert << ">\t.\tPASS\tIMPRECISE;SVTYPE=";
 	convert << trans_type(region.type);
 	convert << ";SVMETHOD=BEDFILE;CHR2=";
 	convert << region.stop.chr;
 	convert << ";END=";
 	convert << region.stop.pos;
-	convert << ";SVLEN=";
+	convert << ";CIPOS=0,0;CIEND=0,0;SVLEN=";
 	convert << region.stop.pos - region.start.pos;
-	convert << ";PE=";
-	convert << 1;
-	convert << "\tGT\t";
-	std::stringstream s;
-	s << "./.";
-	//std::cout<<convert.str()<<std::endl;
+	convert << "\tGT\t.\/.";
 	return convert.str();
 }
 
@@ -392,10 +374,10 @@ void process_bed_file(std::string bedfile, std::string type, std::string output)
 				region.stop.chr += buffer[i];
 			}
 			if (count == 1 && buffer[i - 1] == '\t') {
-				region.start.pos = atoi(&buffer[i]);
+				region.start.pos = atoi(&buffer[i])-1;
 			}
 			if (count == 2 && buffer[i - 1] == '\t') {
-				region.stop.pos = atoi(&buffer[i]);
+				region.stop.pos = atoi(&buffer[i])-1;
 				break;
 			}
 			if (buffer[i] == '\t') {
@@ -436,15 +418,15 @@ void parse_VCF_to_bed(std::string vcffile, int min_size, int max_size, std::stri
 			//	if ((entries[i].type == 0 && entries[i].sv_len < 3000) || (entries[i].type == 4 && entries[i].sv_len < 311)) {
 			fprintf(file, "%s", entries[i].start.chr.c_str());
 			fprintf(file, "%c", '\t');
-			fprintf(file, "%i", entries[i].start.pos);
+			fprintf(file, "%i", entries[i].start.pos+1);
 			fprintf(file, "%c", '\t');
-			fprintf(file, "%i", entries[i].start.pos);
+			fprintf(file, "%i", entries[i].start.pos+1);
 			fprintf(file, "%c", '\t');
 			fprintf(file, "%s", entries[i].stop.chr.c_str());
 			fprintf(file, "%c", '\t');
-			fprintf(file, "%i", entries[i].stop.pos);
+			fprintf(file, "%i", entries[i].stop.pos+1);
 			fprintf(file, "%c", '\t');
-			fprintf(file, "%i", entries[i].stop.pos);
+			fprintf(file, "%i", entries[i].stop.pos+1);
 			fprintf(file, "%c", '\t');
 			fprintf(file, "%s", entries[i].sv_id.c_str());
 			fprintf(file, "%c", '\t');
